==> com.liferay.frontend.taglib-5.1.2.jar: META-INF/resources/diff_version_comparator/components/Diff.js <==
Liferay.Loader.define("frontend-taglib@5.1.2/diff_version_comparator/components/Diff", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/card', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = Diff;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _card = _interopRequireDefault(require("@frontend-taglib-clay$clayui/card"));

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  function Diff(_ref) {
    var diff = _ref.diff,
        onClose = _ref.onClose,
        version = _ref.version;
    return _react["default"].createElement(_card["default"], {
      className: "diff-container-column"
    }, version && _react["default"].createElement(_card["default"].Row, {
      className: "card-row-padded diff-version-filter"
    }, _react["default"].createElement("div", {
      className: "autofit-row"
    }, _react["default"].createElement("div", {
      className: "autofit-col autofit-col-expand"
    }, _react["default"].createElement(_card["default"].Description, {
      displayType: "title"
    }, version.label), _react["default"].createElement(_card["default"].Description, {
      displayType: "subtitle"
    }, version.userName, " ", version.displayDate)), _react["default"].createElement("div", {
      className: "autofit-col"
    }, _react["default"].createElement(_button.ClayButtonWithIcon, {
      displayType: "unstyled",
      onClick: onClose,
      symbol: "times"
    })))), _react["default"].createElement(_card["default"].Row, {
      className: "card-row-padded diff-container"
    }, _react["default"].createElement("div", {
      className: "taglib-diff-html",
      dangerouslySetInnerHTML: {
        __html: diff
      }
    })), _react["default"].createElement(_card["default"].Row, {
      className: "card-row-padded taglib-diff-html"
    }, _react["default"].createElement("span", {
      className: "diff-html-added legend-item"
    }, Liferay.Language.get('added')), _react["default"].createElement("span", {
      className: "diff-html-removed legend-item"
    }, Liferay.Language.get('deleted')), _react["default"].createElement("span", {
      className: "diff-html-changed"
    }, Liferay.Language.get('format-changes'))));
  }
  //# sourceMappingURL=Diff.js.map
});
//# sourceMappingURL=Diff.js.map

==> com.liferay.frontend.taglib-5.4.3.jar: META-INF/resources/diff_version_comparator/components/Diff.js <==
Liferay.Loader.define("frontend-taglib@5.4.3/diff_version_comparator/components/Diff", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/button', '@frontend-taglib-clay$clayui/card', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = Diff;

  var _button = require("@frontend-taglib-clay$clayui/button");

  var _card = _interopRequireDefault(require("@frontend-taglib-clay$clayui/card"));

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  function Diff(_ref) {
    var diff = _ref.diff,
        onClose = _ref.onClose,
        version = _ref.version;
    return _react["default"].createElement(_card["default"], {
      className: "diff-container-column"
    }, version && _react["default"].createElement(_card["default"].Row, {
      className: "card-body diff-version-filter"
    }, _react["default"].createElement("div", {
      className: "autofit-row"
    }, _react["default"].createElement("div", {
      className: "autofit-col autofit-col-expand"
    }, _react["default"].createElement(_card["default"].Description, {
      displayType: "title"
    }, version.label), _react["default"].createElement(_card["default"].Description, {
      displayType: "subtitle"
    }, version.userName, " ", version.displayDate)), _react["default"].createElement("div", {
      className: "autofit-col"
    }, _react["default"].createElement(_button.ClayButtonWithIcon, {
      displayType: "unstyled",
      onClick: onClose,
      symbol: "times"
    })))), _react["default"].createElement(_card["default"].Row, {
      className: "card-body diff-container"
    }, _react["default"].createElement("div", {
      className: "taglib-diff-html",
      dangerouslySetInnerHTML: {
        __html: diff
      }
    })), _react["default"].createElement(_card["default"].Row, {
      className: "card-body taglib-diff-html"
    }, _react["default"].createElement("span", {
      className: "diff-html-added legend-item"
    }, Liferay.Language.get('added')), _react["default"].createElement("span", {
      className: "diff-html-removed legend-item"
    }, Liferay.Language.get('deleted')), _react["default"].createElement("span", {
      className: "diff-html-changed"
    }, Liferay.Language.get('format-changes'))));
  }
  //# sourceMappingURL=Diff.js.map
});
//# sourceMappingURL=Diff.js.map
